@@ -56,19 +56,21 @@ except:
     _brlAPIAvailable = False
     _brlAPIRunning = False
 
+from . import settings
+
 try:
     # This can fail due to gtk not being available.  We want to
     # be able to recover from that if possible.  The main driver
     # for this is to allow "orca --text-setup" to work even if
     # the desktop is not running.
     #
-    import brlmon
+    from . import brlmon
 except:
-    pass
-import debug
-import eventsynthesizer
-import orca_state
-import settings
+    settings.enableBrailleMonitor = False
+
+from . import debug
+from . import eventsynthesizer
+from . import orca_state
 
 # Right now, the orca autogen.sh/configure needs a priori knowledge of
 # where the liblouis tables are.  When running autogen.sh/configure,
@@ -79,7 +81,7 @@ import settings
 # liblouis bindings can give us the tablesdir information at runtime
 # http://code.google.com/p/liblouis/issues/detail?id=9]]
 #
-from orca_platform import tablesdir
+from .orca_platform import tablesdir
 if louis and not tablesdir:
     debug.println(debug.LEVEL_SEVERE,
                   "Contraction tables for liblouis cannot be found.")
@@ -91,7 +93,7 @@ if louis and not tablesdir:
                   "not be available.")
     louis = None
     
-from orca_i18n import _                          # for gettext support
+from .orca_i18n import _                          # for gettext support
 
 # The braille monitor
 #
@@ -351,11 +353,6 @@ class Region:
 
         self.expandOnCursor = expandOnCursor
 
-        try:
-            string = string.decode("UTF-8")
-        except UnicodeEncodeError:
-            pass
-
         # The uncontracted string for the line.
         #
         self.rawLine = string.strip("\n")
@@ -395,7 +392,7 @@ class Region:
 
         # Double check for ellipses.
         #
-        maskSize = len(self.string) + (2 * self.string.count(u'\u2026'))
+        maskSize = len(self.string) + (2 * self.string.count('\u2026'))
 
         # Create an empty mask.
         #
@@ -607,21 +604,6 @@ class Text(Region):
             self.caretOffset = 0
             self.lineOffset = 0
 
-        try:
-            string = string.decode("UTF-8")
-        except UnicodeEncodeError:
-            pass
-        if label:
-            try:
-                label = label.decode("UTF-8")
-            except UnicodeEncodeError:
-                pass
-        if eol:
-            try:
-                eol = eol.decode("UTF-8")
-            except UnicodeEncodeError:
-                pass
-
         try:
             endOffset = endOffset - self.lineOffset
         except TypeError:
@@ -674,7 +656,6 @@ class Text(Region):
         [string, caretOffset, lineOffset] = \
                  orca_state.activeScript.getTextLineAtCaret(self.accessible,
                                                             self.startOffset)
-        string = string.decode("UTF-8")
 
         cursorOffset = min(caretOffset - lineOffset, len(string))
 
@@ -762,7 +743,7 @@ class Text(Region):
             while n < nLinks:
                 link = hyperText.getLink(n)
                 if self.lineOffset <= link.startIndex:
-                    for i in xrange(link.startIndex, link.endIndex):
+                    for i in range(link.startIndex, link.endIndex):
                         try:
                             regionMask[i] |= linkIndicator
                         except:
@@ -790,7 +771,7 @@ class Text(Region):
                 if mask != settings.TEXT_ATTR_BRAILLE_NONE:
                     maskStart = max(startOffset - self.lineOffset, 0)
                     maskEnd = min(endOffset - self.lineOffset, stringLength)
-                    for i in xrange(maskStart, maskEnd):
+                    for i in range(maskStart, maskEnd):
                         regionMask[i] |= attrIndicator
 
         if selIndicator:
@@ -798,7 +779,7 @@ class Text(Region):
             for startOffset, endOffset in selections:
                 maskStart = max(startOffset - self.lineOffset, 0)
                 maskEnd = min(endOffset - self.lineOffset, stringLength)
-                for i in xrange(maskStart, maskEnd):
+                for i in range(maskStart, maskEnd):
                     regionMask[i] |= selIndicator
 
         if self.contracted:
@@ -947,7 +928,7 @@ class Line:
                 # The ultimate solution is to get i18n support into
                 # BrlTTY.]]]
                 #
-                string += region.string.replace(u'\u2026', "...")
+                string += region.string.replace('\u2026', "...")
             mask = region.getAttributeMask(getLinkMask)
             attributeMask += mask
 
@@ -1381,21 +1362,11 @@ def refresh(panToCursor=True,
         cursorCell += 1 # Normalize to 1-based offset
 
     logLine = "BRAILLE LINE:  '%s'" % string
-    try:
-        logLine = logLine.encode("UTF-8")
-    except UnicodeDecodeError:
-        pass
-
     debug.println(debug.LEVEL_INFO, logLine)
     log.info(logLine)
 
     logLine = "     VISIBLE:  '%s', cursor=%d" % \
                     (string[startPos:endPos], cursorCell)
-    try:
-        logLine = logLine.encode("UTF-8")
-    except UnicodeDecodeError:
-        pass
-
     debug.println(debug.LEVEL_INFO, logLine)
     log.info(logLine)
 
@@ -1445,13 +1416,18 @@ def refresh(panToCursor=True,
 
     if settings.enableBrailleMonitor:
         if not _monitor:
-            _monitor = brlmon.BrlMon(_displaySize[0])
-            _monitor.show_all()
+            try:
+                _monitor = brlmon.BrlMon(_displaySize[0])
+                _monitor.show_all()
+            except:
+                debug.println(debug.LEVEL_WARNING, "brlmon failed")
+                _monitor = None
         if attributeMask:
             subMask = attributeMask[startPos:endPos]
         else:
             subMask = None
-        _monitor.writeText(cursorCell, substring, subMask)
+        if _monitor:
+            _monitor.writeText(cursorCell, substring, subMask)
     elif _monitor:
         _monitor.destroy()
         _monitor = None
@@ -1820,6 +1796,9 @@ def init(callback=None, tty=7):
         _brlAPISourceId = GObject.io_add_watch(_brlAPI.fileDescriptor,
                                                GObject.IO_IN,
                                                _brlAPIKeyReader)
+    except NameError:
+        debug.println(debug.LEVEL_CONFIGURATION, "BrlApi is not defined")
+        return False
     except:
         debug.println(debug.LEVEL_CONFIGURATION,
                       "Could not initialize BrlTTY:")
